import json
from pathlib import Path
import requests
from loguru import logger


def sharkimg_upload(imgpath: str, token: str):
    img = Path(imgpath)
    headers = {"Authorization": "Bearer " + token, "Accept": "application/json"}

    files = {'file': open(img, 'rb')}
    try:
        req = requests.post('https://img.sharkpt.net/api/v1/upload', headers=headers, files=files)
        req.encoding = 'utf-8'
    except Exception as r:
        logger.warning('requests 获取失败，原因: %s' % (r))
        return None
    try:
        res = req.json()
    except json.decoder.JSONDecodeError:
        res = {}
    if not req.ok or ('status' in res and res['status'] != True):
        logger.warning(req.content)
        logger.warning(f"上传图片失败: HTTP {req.status_code}, reason: {res.message}")
        return None
    if 'data' not in res or 'links' not in res['data'] or 'url' not in res['data']['links']:
        logger.warning(f"图片直链获取失败")
        return None
    return res['data']['links']['url']


def sharkimg_upload_files(imgpaths: list, token: str, form='img'):
    liststr = ''
    imgnum = 0
    for imgpath in imgpaths:
        imgnum = imgnum + 1
        trynum = 0
        success = 0
        imgstr = ''
        while success == 0 and trynum < 5:
            trynum = trynum + 1
            try:
                imgstr = sharkimg_upload(imgpath, token)
                success = 1
            except Exception as r:
                success = 0
                logger.warning('SHARKIMG第' + str(imgnum) + '张图片' + imgpath + '第' + str(trynum) +
                               '次上传失败，失败原因: %s\n正在重试...' % (r))
            if imgstr == None:
                success = 0
                logger.warning('SHARKIMG第' + str(imgnum) + '张图片' + imgpath + '第' + str(trynum) + '次上传失败，正在重试...')
        if success == 1:
            if form.lower() == 'img':
                liststr = liststr + imgstr + '\n'
            elif form.lower() == 'bbcode':
                liststr = liststr + '[img]' + imgstr + '[/img]\n'
            else:
                liststr = liststr + imgstr + '\n'
            logger.info('SHARKIMG第' + str(imgnum) + '张图片上传成功！')
        else:
            logger.warning('SHARKIMG第' + str(imgnum) + '张图片' + imgpath + '上传失败')
            return ''
    return liststr.strip()


from progress.bar import IncrementalBar
from torf import Torrent
from pathlib import Path
import time
from loguru import logger
import os
def make_private_torrent(filepath: str, torrentname:str, tracker="https://announce.leaguehd.com/announce.php"):
    '''
    if os.path.isdir(filepath):
        logger.info('检测到路径制种，将先删除掉路径里面所有种子文件(torrent后缀)以及隐藏文件（.开头的文件）...')
        deletetorrent(filepath) 
    deletetorrent(os.path.dirname(torrentname))
    logger.info('即将开始制作种子...')
    '''
    torrent_path = Path(torrentname)
    path = Path(filepath)
    piece_size = 4 * 1024 * 1024
    private = True
    created_by = "Upload Machine"
    source = "Upload Machine"
    trytime=0
    filesize=0

    while filesize==0:
        trytime=trytime+1
        if trytime>10:
            logger.error('制作种子失败')
            return
        if trytime>1:
            logger.warning('第'+str(trytime-1)+'次制作种子失败')
        logger.info('正在第'+str(trytime)+'次制作种子:') 
        if torrent_path.exists():
            logger.info('已存在种子文件，正在删除'+torrentname)
            try:
                os.remove(torrent_path)
            except Exception as r:
                logger.error('删除种子发生错误: %s' %(r))
            
        if tracker:
            torrent = Torrent(path=str(path.absolute()), trackers=[tracker], piece_size=piece_size, private=private, created_by=created_by, source=source)
        else:
            torrent = Torrent(path=str(path.absolute()), piece_size=piece_size, private=private,  created_by=created_by)
        bar = IncrementalBar(message="制种中:", max=torrent.pieces,suffix="%(index)d/%(max)d [%(eta_td)s]")

        def cb(__torrent: Torrent, path: str, hashed_pieces: int, total_pieces: int):
            bar.next()

        torrent.generate(callback=cb, interval=0)
        torrent.write(str(torrent_path))
        bar.finish()
        filesizetime=0
        while filesize==0:
            filesizetime=filesizetime+1
            if filesizetime>5:
                break
            if os.path.exists(torrentname):
                filesize=os.path.getsize(torrentname)
            else:
                filesize=0
            if filesize==0:
                time.sleep(1)
    logger.info('已完成制作种子'+torrentname)
    return 


from loguru import logger
import time
import os
from upload_machine.utils.uploader.upload_tools import *
import re
import cloudscraper

def hhclub_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
    post_url = "https://hhanclub.top/takeupload.php"
    tags=[]
    time_out=40
    if (file1.pathinfo.type=='anime' or file1.pathinfo.type=='tv') and file1.pathinfo.collection==0:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename+'第'+file1.episodename+'集'
    else:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename


    #选择类型
    if 'anime' in file1.pathinfo.type.lower():
        select_type='405'
    elif 'tv' in file1.pathinfo.type.lower() and file1.pathinfo.collection>=1:
        if '大陆' in file1.country or '香港' in file1.country or '台湾' in file1.country:
            select_type='402'
        else:
            select_type='402'
    elif 'tv' in file1.pathinfo.type.lower() and file1.pathinfo.collection==0:
        if '大陆' in file1.country or '香港' in file1.country or '台湾' in file1.country:
            select_type='402'
        else:
            select_type='402'
    elif 'movie' in file1.pathinfo.type.lower():
        select_type='401'
    elif 'show' in file1.pathinfo.type.lower():
        select_type='403'
    elif 'doc' in file1.pathinfo.type.lower():
        select_type='404'
    elif 'mv' in file1.pathinfo.type.lower():
        select_type='406'
    elif 'sport' in file1.pathinfo.type.lower():
        select_type='407'
    elif 'music' in file1.pathinfo.type.lower():
        select_type='409'
    else:
        select_type='405'
    logger.info('已成功填写类型为'+file1.pathinfo.type)

    #选择来源
    if 'web' in file1.type.lower():
        source_sel='2'
    elif (file1.type=='bluray' or 'bd' in file1.type.lower()) and '2160' in file1.standard_sel:
        source_sel='7'
    elif file1.type=='bluray' or 'bd' in file1.type.lower():
        source_sel='1'
    elif 'dvd' in file1.type.lower()  :
        source_sel='3'
    elif file1.type=='HDTV':
        source_sel='4'
    elif file1.type=='remux':
        source_sel='1'
    else:
        source_sel='6'
    logger.info('已成功填写来源为'+file1.type)

    #选择媒介
    if 'web' in file1.type.lower() and 'dl' in file1.type.lower():
        medium_sel='10'
    elif (file1.type=='bluray') and '2160' in file1.standard_sel:
        medium_sel='1'
    elif file1.type=='bluray':
        medium_sel='1'
    elif 'rip' in file1.type.lower() and  'web' in file1.type.lower():
        medium_sel='7'
    elif 'rip' in file1.type.lower() and 'dvd' in file1.type.lower():
        medium_sel='6'
    elif 'rip' in file1.type.lower()  :
        medium_sel='7'
    elif 'HDTV' in file1.type.upper() and '2160' in file1.standard_sel:
        medium_sel='5'
    elif 'HDTV' in file1.type.upper():
        medium_sel='5'
    elif 'remux' in file1.type.lower():
        medium_sel='3'
    elif 'dvd' in file1.type.lower():
        medium_sel='7'
    else:
        medium_sel='19'
    logger.info('已成功选择媒介为'+file1.type)


    #选择编码
    if file1.Video_Format=='H264':
        codec_sel='1'
    elif file1.Video_Format=='x264':
        codec_sel='1'
    elif file1.Video_Format=='H265':
        codec_sel='6'
    elif file1.Video_Format=='x265':
        codec_sel='6'
    else:
        codec_sel='6'
    logger.info('已成功选择编码为'+file1.Video_Format)

    #选择音频编码
    if file1.Audio_Format.upper()=='AAC':
        audiocodec_sel='6'
    elif 'DTS-HDMA' in file1.Audio_Format.upper() or 'DTS-HD MA' in file1.Audio_Format.upper():
        audiocodec_sel='3'
    elif 'TRUEHD ATMOS' in file1.Audio_Format.upper():
        audiocodec_sel='7'
    elif 'LPCM' in file1.Audio_Format.upper():
        audiocodec_sel='7'
    elif 'TRUEHD' in file1.Audio_Format.upper():
        audiocodec_sel='7'
    elif 'FLAC' in file1.Audio_Format.upper():
        audiocodec_sel='1'
    elif 'APE' in file1.Audio_Format.upper():
        audiocodec_sel='2'
    elif 'MP3' in file1.Audio_Format.upper():
        audiocodec_sel='4'
    elif 'AC3' in file1.Audio_Format.upper() or 'AC-3' in file1.Audio_Format.upper() or 'DD' in file1.Audio_Format.upper():
        audiocodec_sel='8'
    elif 'DTS:X' in file1.Audio_Format.upper() or 'DTS-X' in file1.Audio_Format.upper():
        audiocodec_sel='3'
    elif 'DTS' in file1.Audio_Format.upper():
        audiocodec_sel='3'
    elif 'WAV' in file1.Audio_Format.upper():
        audiocodec_sel='7'
    elif 'M4A' in file1.Audio_Format.upper():
        audiocodec_sel='7'
    else:
        audiocodec_sel='7'
    logger.info('已成功选择音频编码为'+file1.Audio_Format.upper())

    #选择分辨率
    if '8K' in file1.standard_sel:
        standard_sel='1'
    elif '2160' in file1.standard_sel:
        standard_sel='1'
    elif '1080p' in file1.standard_sel.lower():
        standard_sel='2'
    elif '1080i' in file1.standard_sel.lower():
        standard_sel='2'
    elif '720' in file1.standard_sel:
        standard_sel='3'
    elif '480' in file1.standard_sel:
        standard_sel='4'
    else:
        standard_sel='2'
    logger.info('已成功选择分辨率为'+file1.standard_sel)
    
    #选择地区
    if not file1.country=='':
        if '大陆' in file1.country:
            processing_sel='8'
            logger.info('国家信息已选择'+file1.country)
        elif '香港' in file1.country:
            processing_sel='6'
            logger.info('国家信息已选择'+file1.country)
        elif '台湾' in file1.country:
            processing_sel='7'
            logger.info('国家信息已选择'+file1.country)
        elif '美国' in file1.country:
            processing_sel='3'
            logger.info('国家信息已选择'+file1.country)
        elif '英国' in file1.country:
            processing_sel='9'
            logger.info('国家信息已选择'+file1.country)
        elif '法国' in file1.country:
            processing_sel='9'
            logger.info('国家信息已选择'+file1.country)
        elif '韩国' in file1.country:
            processing_sel='5'
            logger.info('国家信息已选择'+file1.country)
        elif '日本' in file1.country:
            processing_sel='4'
            logger.info('国家信息已选择'+file1.country)
        elif '印度' in file1.country:
            processing_sel='9'
            logger.info('国家信息已选择'+file1.country)
        else:
            processing_sel='9'
            logger.info('未找到资源国家信息，已选择其他')
    else:
        processing_sel='4'
        logger.info('未找到资源国家信息，已默认日本')

    #选择制作组
    if 'HHWEB' in file1.sub.upper():
        team_sel='1'
    else:
        team_sel='5'
    logger.info('制作组已成功选择为'+file1.sub)
    
    if 'HHWEB' in file1.sub.upper():
        # tags.append(2)
        tags.append(3)
        # tags.append(4)
    if 'hhclub' in file1.pathinfo.exclusive :
        tags.append(1)
        logger.info('已选择禁转')
    if '国' in file1.language or '中' in file1.language:
        tags.append(5)
        logger.info('已选择国语')
    if '粤' in file1.language:
        tags.append(10)
        logger.info('已选择粤语')
    if not file1.sublan=='' and ('简' in file1.sublan or '繁' in file1.sublan or '中' in file1.sublan):
        tags.append(6)
        logger.info('已选择中字')

    
    tags=list(set(tags))
    tags.sort()
    
    if siteinfo.uplver==1:
        uplver='yes'
    else:
        uplver='no'

    torrent_file = file1.torrentpath
    file_tup = ("file", (os.path.basename(torrent_file), open(torrent_file, 'rb'), 'application/x-bittorrent')),
            

    other_data = {
            "name": file1.uploadname,
            "small_descr": file1.small_descr+file1.pathinfo.exinfo,
            "pt_gen": file1.doubanurl,
            "color": "0",
            "font": "0",
            "size": "0",
            "descr": file1.content,
            "type": select_type,
            "source_sel[5]" : source_sel,
            "medium_sel[5]": medium_sel,
            "codec_sel[5]": codec_sel,
            "audiocodec_sel[5]": audiocodec_sel,
            "standard_sel[5]": standard_sel,
            "processing_sel[5]" : processing_sel,
            "team_sel[5]": team_sel,
            "uplver": uplver,
            "tags[5][]": tags,
            }

    scraper=cloudscraper.create_scraper()
    success_upload=0
    try_upload=0
    while success_upload==0:
        try_upload+=1
        if try_upload>5:
            return False,fileinfo+' 发布种子发生请求错误,请确认站点是否正常运行'
        logger.info('正在发布种子')
        try:
            r = scraper.post(post_url, cookies=cookies_raw2jar(siteinfo.cookie),data=other_data, files=file_tup,timeout=time_out)
            success_upload=1
        except Exception as r:
            logger.warning('发布种子发生错误: %s' %(r))
            success_upload=0
    
    return afterupload(r,fileinfo,record_path,siteinfo,file1,qbinfo,hashlist)


from loguru import logger
import time
import os
from upload_machine.utils.uploader.upload_tools import *
import re
import cloudscraper
from bs4 import BeautifulSoup
def get_token(cookie):
    headers = {
            'authority': 'zhuque.in',
            'accept': 'application/json, text/plain, */*',
            'accept-language': 'zh-CN,zh;q=0.9,en;q=0.8,en-GB;q=0.7,en-US;q=0.6',
            'cookie': cookie,
            'origin': 'https://zhuque.in',
            'referer': 'https://zhuque.in/torrent/upload',
            'sec-ch-ua': '"Not?A_Brand";v="8", "Chromium";v="108", "Microsoft Edge";v="108"',
            'sec-ch-ua-mobile': '?0',
            'sec-ch-ua-platform': '"macOS"',
            'sec-fetch-dest': 'empty',
            'sec-fetch-mode': 'cors',
            'sec-fetch-site': 'same-origin',
            'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/108.0.0.0 Safari/537.36 Edg/108.0.1462.54',
    }
    scraper=cloudscraper.create_scraper()
    r = scraper.get('https://zhuque.in/index',headers=headers)
    soup = BeautifulSoup(r.text,'lxml')
    res=soup.find_all('meta',{'name':'x-csrf-token'})
    if len(res)<=0:
        return ''
    if not 'content' in res[0].attrs:
        return ''
    return res[0].attrs['content']
def zhuque_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
    post_url = "https://zhuque.in/api/torrent/upload"
    tags=[]
    time_out=40
    if (file1.pathinfo.type=='anime' or file1.pathinfo.type=='tv') and file1.pathinfo.collection==0:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename+'第'+file1.episodename+'集'
    else:
        fileinfo=file1.chinesename+'在'+siteinfo.sitename


    #选择类型
    if 'anime' in file1.pathinfo.type.lower():
        select_type='503'
    elif 'tv' in file1.pathinfo.type.lower() and file1.pathinfo.collection>=1:
        if '大陆' in file1.country or '香港' in file1.country or '台湾' in file1.country:
            select_type='502'
        else:
            select_type='502'
    elif 'tv' in file1.pathinfo.type.lower() and file1.pathinfo.collection==0:
        if '大陆' in file1.country or '香港' in file1.country or '台湾' in file1.country:
            select_type='502'
        else:
            select_type='502'
    elif 'movie' in file1.pathinfo.type.lower():
        select_type='501'
    elif 'show' in file1.pathinfo.type.lower():
        select_type='504'
    elif 'doc' in file1.pathinfo.type.lower():
        select_type='599'
    elif 'mv' in file1.pathinfo.type.lower():
        select_type='599'
    elif 'sport' in file1.pathinfo.type.lower():
        select_type='599'
    elif 'music' in file1.pathinfo.type.lower():
        select_type='599'
    else:
        select_type='599'
    logger.info('已成功填写类型为'+file1.pathinfo.type)

    #选择媒介
    if 'web' in file1.type.lower() and 'dl' in file1.type.lower():
        medium_sel='309'
    elif (file1.type=='bluray') and '2160' in file1.standard_sel:
        medium_sel='301'
    elif file1.type=='bluray':
        medium_sel='303'
    elif 'rip' in file1.type.lower() and  'web' in file1.type.lower():
        medium_sel='306'
    elif 'rip' in file1.type.lower() and 'dvd' in file1.type.lower():
        medium_sel='306'
    elif 'rip' in file1.type.lower()  :
        medium_sel='306'
    elif 'HDTV' in file1.type.upper() and '2160' in file1.standard_sel:
        medium_sel='307'
    elif 'HDTV' in file1.type.upper():
        medium_sel='308'
    elif 'remux' in file1.type.lower():
        medium_sel='305'
    elif 'dvd' in file1.type.lower():
        medium_sel='399'
    else:
        medium_sel='399'
    logger.info('已成功选择媒介为'+file1.type)


    #选择编码
    if file1.Video_Format=='H264':
        codec_sel='101'
    elif file1.Video_Format=='x264':
        codec_sel='103'
    elif file1.Video_Format=='H265':
        codec_sel='102'
    elif file1.Video_Format=='x265':
        codec_sel='104'
    else:
        codec_sel='101'
    logger.info('已成功选择编码为'+file1.Video_Format)

    #选择音频编码
    if file1.Audio_Format.upper()=='AAC':
        audiocodec_sel='201'
    elif 'DTS-HDMA' in file1.Audio_Format.upper() or 'DTS-HD MA' in file1.Audio_Format.upper():
        audiocodec_sel='204'
    elif 'TRUEHD ATMOS' in file1.Audio_Format.upper():
        audiocodec_sel='206'
    elif 'LPCM' in file1.Audio_Format.upper():
        audiocodec_sel='210'
    elif 'TRUEHD' in file1.Audio_Format.upper():
        audiocodec_sel='205'
    elif 'FLAC' in file1.Audio_Format.upper():
        audiocodec_sel='209'
    elif 'APE' in file1.Audio_Format.upper():
        audiocodec_sel='299'
    elif 'MP3' in file1.Audio_Format.upper():
        audiocodec_sel='299'
    elif 'DDP' in file1.Audio_Format.upper():
        audiocodec_sel='207'
    elif 'AC3' in file1.Audio_Format.upper() or 'AC-3' in file1.Audio_Format.upper() or 'DD' in file1.Audio_Format.upper():
        audiocodec_sel='208'
    elif 'DTS:X' in file1.Audio_Format.upper() or 'DTS-X' in file1.Audio_Format.upper():
        audiocodec_sel='203'
    elif 'DTS' in file1.Audio_Format.upper():
        audiocodec_sel='202'
    elif 'WAV' in file1.Audio_Format.upper():
        audiocodec_sel='299'
    elif 'M4A' in file1.Audio_Format.upper():
        audiocodec_sel='299'
    else:
        audiocodec_sel='299'
    logger.info('已成功选择音频编码为'+file1.Audio_Format.upper())

    #选择分辨率
    if '8K' in file1.standard_sel:
        standard_sel='499'
    elif '2160' in file1.standard_sel:
        standard_sel='404'
    elif '1080p' in file1.standard_sel.lower():
        standard_sel='403'
    elif '1080i' in file1.standard_sel.lower():
        standard_sel='402'
    elif '720' in file1.standard_sel:
        standard_sel='401'
    elif '480' in file1.standard_sel:
        standard_sel='499'
    else:
        standard_sel='499'
    logger.info('已成功选择分辨率为'+file1.standard_sel)
    

    #选择制作组
    if 'ZHUQUE' in file1.sub.upper():
        team_sel='4001'
    elif 'HARES' in file1.sub.upper():
        team_sel='4101'
    elif 'HARESWEB' in file1.sub.upper():
        team_sel='4102'
    elif 'HARESTV' in file1.sub.upper():
        team_sel='4103'
    elif 'OURBITS' in file1.sub.upper():
        team_sel='4201'
    elif 'OURTV' in file1.sub.upper():
        team_sel='4202'
    elif 'FLTTH' in file1.sub.upper():
        team_sel='4203'
    elif 'ILOVETV' in file1.sub.upper():
        team_sel='4204'
    elif 'MTEAM' in file1.sub.upper():
        team_sel='4211'
    elif 'GEEK' in file1.sub.upper():
        team_sel='4212'
    elif 'CMCT' in file1.sub.upper():
        team_sel='4221'
    elif 'CMCTV' in file1.sub.upper():
        team_sel='4222'
    elif 'DREAM' in file1.sub.upper():
        team_sel='4241'
    elif 'DBTV' in file1.sub.upper():
        team_sel='4242'
    elif 'QHSTUDIO' in file1.sub.upper():
        team_sel='4243'
    else:
        team_sel='4999'
    logger.info('制作组已成功选择为'+file1.sub)
    

    if 'ZHUQUE' in file1.sub.upper():
        tags.append(601)
        logger.info('已选择官方')
    if 'zhuque' in file1.pathinfo.exclusive :
        tags.append(602)
        logger.info('已选择禁转')
    if '国' in file1.language or '中' in file1.language:
        tags.append(603)
        logger.info('已选择国语')
    '''
    if '粤' in file1.language:
        tags.append(10)
        logger.info('已选择粤语')
    '''
    if not file1.sublan=='' and ('简' in file1.sublan or '繁' in file1.sublan or '中' in file1.sublan):
        tags.append(604)
        logger.info('已选择中字')

    
    tags=list(set(tags))
    tags.sort()
    tags=[str(titem) for titem in tags]
    if siteinfo.uplver==1:
        uplver='true'
    else:
        uplver='false'
        
        

    torrent_file = file1.torrentpath
    file_tup = ("torrent", (os.path.basename(torrent_file), open(torrent_file, 'rb'), 'application/x-bittorrent')),
    token=get_token(siteinfo.cookie)
    if token=='' and siteinfo.token=='':
        return False,fileinfo+' 发布种子发生错误,错误信息:朱雀缺少站点token信息，请联系站点/莫与解决'
    elif token=='':
        token=siteinfo.token
    headers = {
            'authority': 'zhuque.in',
            'accept': 'application/json, text/plain, */*',
            'accept-language': 'zh-CN,zh;q=0.9,en;q=0.8,en-GB;q=0.7,en-US;q=0.6',
            'cookie': siteinfo.cookie,
            'origin': 'https://zhuque.in',
            'referer': 'https://zhuque.in/torrent/upload',
            'sec-ch-ua': '"Not?A_Brand";v="8", "Chromium";v="108", "Microsoft Edge";v="108"',
            'sec-ch-ua-mobile': '?0',
            'sec-ch-ua-platform': '"macOS"',
            'sec-fetch-dest': 'empty',
            'sec-fetch-mode': 'cors',
            'sec-fetch-site': 'same-origin',
            'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/108.0.0.0 Safari/537.36 Edg/108.0.1462.54',
            'x-csrf-token': token,
    }
    other_data = {
            "title": file1.uploadname,
            "subtitle": file1.small_descr+file1.pathinfo.exinfo,
            "doubanid": re.findall('subject/(\d+)',file1.doubanurl)[0],
            "screenshot": file1.screenshoturl.replace('[img]','').replace('[/img]',''),
            "mediainfo": file1.mediainfo,
            "category": select_type,
            "medium": medium_sel,
            "videoCoding": codec_sel,
            "audioCoding": audiocodec_sel,
            "resolution": standard_sel,
            "group": team_sel,
            "anonymous": uplver,
            "tags": ','.join(tags),
            "note": '',
            }
    scraper=cloudscraper.create_scraper()
    success_upload=0
    try_upload=0
    while success_upload==0:
        try_upload+=1
        if try_upload>5:
            return False,fileinfo+' 发布种子发生请求错误,请确认站点是否正常运行'
        logger.info('正在发布种子')
        try:
            r = scraper.post(post_url, headers=headers,data=other_data, files=file_tup,timeout=time_out)
            success_upload=1
        except Exception as r:
            logger.warning('发布种子发生错误: %s' %(r))
            success_upload=0
        
    return afterupload(r,fileinfo,record_path,siteinfo,file1,qbinfo,hashlist)


import json
from pathlib import Path
from typing import Optional
from urllib.parse import urlparse
import requests
from loguru import logger
import os

def rousi_upload(imgpath: str):
    file = {"file" : (os.path.basename(imgpath), open(imgpath,'rb'),'image/'+os.path.splitext(imgpath)[-1])}
    r = requests.post('https://p.rousi.zip/api/v1/upload',files=file)
    if r.status_code == 200:
        res = json.loads(r.text)
        if res['status']:
            logger.info(f'Uploading image succeed!')
            return res['data']['links']['url']
    logger.error(f'Rousi uploading image failed:'+str(r.status_code))
    return None

def rousi_upload_files(imgpaths: list[str], form='img'):
    liststr=''
    imgnum=0
    for imgpath in imgpaths:
        imgnum=imgnum+1
        trynum=0
        success=0
        imgstr=''
        while success==0 and trynum<5:
            trynum=trynum+1
            try:
                imgstr=rousi_upload(imgpath)
                success=1
            except Exception as r:
                success=0
                logger.warning('Rousi第'+str(imgnum)+'张图片'+imgpath+'第'+str(trynum)+'次上传失败，失败原因: %s\n正在重试...' %(r))
            if imgstr==None:
                success=0
                logger.warning('Rousi第'+str(imgnum)+'张图片'+imgpath+'第'+str(trynum)+'次上传失败，正在重试...')
        if success==1:
            if form.lower()=='img':
                liststr=liststr+imgstr+'\n'
            elif form.lower()=='bbcode':
                liststr=liststr+'[img]'+imgstr+'[/img]\n'
            else:
                liststr=liststr+imgstr+'\n'
            logger.info('Rousi第'+str(imgnum)+'张图片上传成功！')
        else:
            logger.warning('Rousi第'+str(imgnum)+'张图片'+imgpath+'上传失败')
            return ''
    return liststr.strip()



from setuptools import setup

setup(
    name='upload_hdkylin',
    version='0.0.1',
    packages=['utils', 'utils.site', 'utils.signer', 'utils.pathinfo', 'utils.rss_ctrl', 'utils.uploader',
              'utils.mediafile', 'utils.para_ctrl', 'utils.img_upload', 'utils.edittorrent', 'utils.seed_machine'],
    url='',
    license='',
    author='moyan',
    author_email='',
    description='一键转种'
)



from upload_machine.utils.uploader.piggo_upload import piggo_upload
from upload_machine.utils.uploader.hdsky_upload import hdsky_upload
from upload_machine.utils.uploader.audience_upload import audience_upload
from upload_machine.utils.uploader.ssd_upload import ssd_upload
from upload_machine.utils.uploader.pter_upload import pter_upload
from upload_machine.utils.uploader.hhclub_upload import hhclub_upload
from upload_machine.utils.uploader.lemonhd_upload import lemonhd_upload
from upload_machine.utils.uploader.hdpt_upload import hdpt_upload
from upload_machine.utils.uploader.wintersakura_upload import wintersakura_upload
from upload_machine.utils.uploader.carpt_upload import carpt_upload
from upload_machine.utils.uploader.hdfans_upload import hdfans_upload
from upload_machine.utils.uploader.hdkylin_upload import hdkylin_upload
from upload_machine.utils.uploader.ptvicomo_upload import ptvicomo_uploadc
from upload_machine.utils.uploader.hares_upload import hares_upload
from upload_machine.utils.uploader.zmpt_upload import zmpt_upload
from upload_machine.utils.uploader.hdvideo_upload import hdvideo_upload
from upload_machine.utils.uploader.ihdbits_upload import ihdbits_upload
from upload_machine.utils.uploader.redleaves_upload import redleaves_upload
from upload_machine.utils.uploader.mteam_upload import mteam_upload
from upload_machine.utils.uploader.sharkpt_upload import sharkpt_upload
from upload_machine.utils.uploader.zhuque_upload import zhuque_upload
from upload_machine.utils.uploader.dajiao_upload import dajiao_upload
from upload_machine.utils.uploader.pandapt_upload import pandapt_upload
from upload_machine.utils.uploader.rousi_upload import rousi_upload





def auto_upload(siteitem,file,record_path,qbinfo,basic,hashlist):
    return eval(siteitem.sitename+'_upload(siteitem,file,record_path,qbinfo,basic,hashlist)')